@@ -2,10 +2,18 @@ import abc
 
 
 class IRabbitmqSetup(object):
-    def publish(self, exchange: str, payload: str, routing_key: str = ''):
+    @abc.abstractmethod
+    def publish(self, exchange: str, payload: str, routing_key: str = '', content_type: str = None,
+                headers: dict = None):
         """Publish a message with a payload to the given exchange and optional routing-key."""
         pass
 
+    @abc.abstractmethod
+    def publish_json(self, exchange: str, payload: dict, routing_key: str = '', headers: dict = None):
+        """Publish a JSON message to the given exchange and optional routing-key. Content-type will be
+        'application/json'."""
+        pass
+
 
 class IRabbitmqVerify(object):
     @abc.abstractmethod
@@ -19,10 +27,16 @@ class IRabbitmqVerify(object):
         """Returns True if a message with the given payload has been published to the given exchange and routing key."""
         pass
 
+    @abc.abstractmethod
+    def payload_published_json(self, exchange: str, expected_payload: dict, routing_key: str = '') -> bool:
+        """Returns True if a JSON message with the given payload has been published to the given exchange and routing
+        key."""
+        pass
+
 
 class IRabbitmqBehavior(object):
     DEFAULT_CONFIG = {
-        'autoCreate': True
+        'auto_create': True
     }
 
     @abc.abstractmethod
