@@ -4,15 +4,16 @@ from touchstone import common
 from touchstone.bootstrap import Bootstrap
 
 
-def execute():
+def execute(should_log_services=False):
     if not common.sanity_check_passes():
         exit(1)
-    bootstrap = Bootstrap()
+    bootstrap = Bootstrap(False, should_log_services)
     print(figlet_format('Touchstone', font='larry3d'))
 
     try:
         bootstrap.mocks.start()
-        bootstrap.services.start(bootstrap.mocks.environment_vars())
+        bootstrap.services.add_environment_vars(bootstrap.mocks.environment_vars())
+        bootstrap.services.start()
         bootstrap.mocks.services_became_available()
         tests_did_pass = bootstrap.services.run_all_tests()
         if tests_did_pass:
